==> img0ch-2.1.9.zip: img0ch/_template/zeromin2/filter_load_ngword.cs <==
<?cs include:"zeromin2/header.cs" ?>

<?cs if:BBS ?><?cs include:"zeromin2/menu_bbs.cs" ?><?cs else ?><?cs include:"zeromin2/menu.cs" ?><?cs /if ?>

<div id="sidebar">
  <div>
    <p class="title"></p>
    <a href="<?cs var:html_escape(ZerominScript) ?>?class=filter&amp;method=load_ip&amp;bbs=<?cs var:html_escape(BBS) ?>&amp;item=<?cs var:html_escape(Item) ?>&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>" onclick="Zeromin2.redirect(this);return false">IPアドレス制限</a><br />
    <a href="<?cs var:html_escape(ZerominScript) ?>?class=filter&amp;method=load_host&amp;bbs=<?cs var:html_escape(BBS) ?>&amp;item=<?cs var:html_escape(Item) ?>&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>" onclick="Zeromin2.redirect(this);return false">ホスト制限</a><br />
  </div>
</div>

<div id="main">

<form id="filterNGWordContainerForm" action="<?cs var:html_escape(ZerominScript) ?>" method="post">

<div id="navhead">
  <hr />
  <a href="<?cs var:html_escape(ZerominScript) ?>?class=bbs&amp;method=load&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>" onclick="Zeromin2.redirect(this);return false">掲示板管理</a>
  &gt;
<?cs if:BBS ?>
  <a href="<?cs var:html_escape(ZerominScript) ?>?class=bbs&amp;method=load_index&amp;bbs=<?cs var:html_escape(BBS) ?>&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>" onclick="Zeromin2.redirect(this);return false">インデックス</a>
  &gt;
<?cs /if ?>
  <a href="<?cs var:html_escape(ZerominScript) ?>?class=filter&amp;method=load_ip&amp;bbs=<?cs var:html_escape(BBS) ?>&amp;item=<?cs var:html_escape(Item) ?>&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>" onclick="Zeromin2.redirect(this);return false">アクセス制限</a>
  &gt;
  <a href="<?cs var:html_escape(ZerominScript) ?>?class=filter&amp;method=load_ngword&amp;bbs=<?cs var:html_escape(BBS) ?>&amp;item=<?cs var:html_escape(Item) ?>&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>" onclick="Zeromin2.redirect(this);return false">NGワード制限</a>
</div>

<h1>NGワード制限</h1>

<?cs if:Code0 ?>
<?cs if:Done_filter_create_ngword ?><div class="noticeSuccess" id="notify"><p>NGワードを新規登録しました</p></div><?cs /if ?>
<?cs if:Done_filter_edit_ngword ?><div class="noticeSuccess" id="notify"><p>NGワードを編集しました</p></div><?cs /if ?>
<?cs if:Done_filter_remove_ngword ?><div class="noticeSuccess" id="notify"><p>選択されたNGワードを削除しました</p></div><?cs /if ?>
<?cs if:Done_filter_load_ngword ?><div class="" id="notify"></div><?cs /if ?>
<?cs else ?>
<?cs if:Code1 ?><div class="noticeFailed" id="notify"><p>実行権限がありません</p></div><?cs /if ?>
<?cs if:Code2 ?><div class="noticeFailed" id="notify"><p>削除するNGワードが選択されていません</p></div><?cs /if ?>
<?cs /if ?>

<p>
現在書き込みを禁止しているNGワードを表示しています。<br />
<a href="<?cs var:html_escape(ZerominScript) ?>?class=filter&amp;method=create_ngword&amp;bbs=<?cs var:html_escape(BBS) ?>&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>" onclick="Zeromin2.redirect(this);return false">NGワードの新規登録はこちらから行ってください。</a><br />
<span class="caution">※注意&nbsp;規制する際はプラグイン一覧の<pre>Img0ch::Plugin::Filter::NGWord</pre>を必ず有効にする必要があります！</span>
</p>

<p>
<select name="method">
  <option value="load_ngword">NGワードの一覧を表示</option>
  <option value="remove_ngword">NGワードの削除</option>
</select>
<input type="submit" value="実行" />
</p>

<p>
ページ単位：
<input type="text" name="item" size="5" value="<?cs var:html_escape(Item) ?>" /><br />
(&nbsp;<?cs var:html_escape(Total) ?>件&nbsp;-&nbsp;現在<?cs var:html_escape(Current) ?>ページ目&nbsp;)<br />
<span class="page">
<?cs if:Prev ?><a href="<?cs var:html_escape(ZerominScript) ?>?class=filter&amp;method=load_ngword&amp;bbs=<?cs var:html_escape(BBS) ?>&amp;by=<?cs var:html_escape(By) ?>&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>&amp;item=<?cs var:html_escape(Item) ?>&amp;offset=<?cs var:html_escape(Prev) ?>" onclick="Zeromin2.redirect(this);return false">&lt;&lt;&nbsp;前</a><?cs /if ?>
<?cs each:item = Pages ?>
<a href="<?cs var:html_escape(ZerominScript) ?>?class=filter&amp;method=load_ngword&amp;bbs=<?cs var:html_escape(BBS) ?>&amp;by=<?cs var:html_escape(By) ?>&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>&amp;item=<?cs var:html_escape(Item) ?>&amp;offset=<?cs var:html_escape(item.num) ?>" onclick="Zeromin2.redirect(this);return false"><?cs var:html_escape(item.num) ?></a>
<?cs /each ?>
<?cs if:Next ?><a href="<?cs var:html_escape(ZerominScript) ?>?class=filter&amp;method=load_ngword&amp;bbs=<?cs var:html_escape(BBS) ?>&amp;by=<?cs var:html_escape(By) ?>&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>&amp;item=<?cs var:html_escape(Item) ?>&amp;offset=<?cs var:html_escape(Next) ?>" onclick="Zeromin2.redirect(this);return false">次&nbsp;&gt;&gt;</a><?cs /if ?>
</span>
</p>

<table class="simple">
  <thead>
  <tr>
    <th><input type="checkbox" name="" value="" onclick="Zeromin2.selectAllCheckbox( this, 'id' )" /></th>
    <th>対象文字列</th>
    <th>対処方法</th>
    <th>置換文字列</th>
  </tr>
  </thead>
  <tbody>
  <?cs each:item = Entries ?>
  <tr>
    <td><input type="checkbox" name="id" value="<?cs var:html_escape(item.id) ?>" /></td>
    <td><a href="<?cs var:html_escape(ZerominScript) ?>?class=filter&amp;method=edit_ngword&amp;id=<?cs var:url_escape(item.id) ?>&amp;bbs=<?cs var:html_escape(BBS) ?>&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>" onclick="Zeromin2.redirect(this);return false"><?cs var:html_escape(item.entry) ?></a></td>
    <td><?cs var:html_escape(item.type) ?></td>
    <td><?cs var:html_escape(item.to) ?></td>
  </tr>
  <?cs /each ?>
  </tbody>
</table>

<p>
  ※「対処方法」の数字について
  <ul>
    <li>1 - 書き込み禁止</li>
    <li>2 - 対象文字列の削除</li>
    <li>4 - 対象文字列を置換文字列に置換</li>
  </ul>
</p>

<div class="formFooter">
<input type="hidden" name="<?cs var:html_escape(SessionName) ?>" value="<?cs var:html_escape(Session) ?>" />
<input type="hidden" name="token" value="<?cs var:html_escape(Token) ?>" />
<input type="hidden" name="class" value="filter" />
<input type="hidden" name="bbs" value="<?cs var:html_escape(BBS) ?>" />
<input type="hidden" name="OK" value="load_ngword" />
<input type="hidden" name="NG" value="load_ngword" />
<br id="endmain" />
</div>

</form>

</div>

<?cs include:"zeromin2/footer.cs" ?>

==> img0ch-2.1.18.zip: img0ch/_template/zeromin2/filter_load_ngword.cs <==
<?cs include:"zeromin2/header.cs" ?>

<?cs if:BBS ?><?cs include:"zeromin2/menu_bbs.cs" ?><?cs else ?><?cs include:"zeromin2/menu.cs" ?><?cs /if ?>

<?cs include:"zeromin2/filter_side_menu.cs" ?>

<div id="main">

<form id="filterNGWordContainerForm" action="<?cs var:html_escape(ZerominScript) ?>" method="post">

<div id="navhead">
  <hr />
  <a href="<?cs var:html_escape(ZerominScript) ?>?class=bbs&amp;method=load&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>" onclick="Zeromin2.redirect(this);return false">掲示板管理</a>
  &gt;
<?cs if:BBS ?>
  <a href="<?cs var:html_escape(ZerominScript) ?>?class=bbs&amp;method=load_index&amp;bbs=<?cs var:html_escape(BBS) ?>&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>" onclick="Zeromin2.redirect(this);return false">インデックス</a>
  &gt;
<?cs /if ?>
  <a href="<?cs var:html_escape(ZerominScript) ?>?class=filter&amp;method=load_ip&amp;bbs=<?cs var:html_escape(BBS) ?>&amp;item=<?cs var:html_escape(Item) ?>&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>" onclick="Zeromin2.redirect(this);return false">アクセス制限</a>
  &gt;
  <a href="<?cs var:html_escape(ZerominScript) ?>?class=filter&amp;method=load_ngword&amp;bbs=<?cs var:html_escape(BBS) ?>&amp;item=<?cs var:html_escape(Item) ?>&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>" onclick="Zeromin2.redirect(this);return false">NGワード制限</a>
</div>

<h1>NGワード制限</h1>

<?cs if:Code0 ?>
<?cs if:Done_filter_create_ngword ?><div class="noticeSuccess" id="notify"><p>NGワードを新規登録しました</p></div><?cs /if ?>
<?cs if:Done_filter_edit_ngword ?><div class="noticeSuccess" id="notify"><p>NGワードを編集しました</p></div><?cs /if ?>
<?cs if:Done_filter_remove_ngword ?><div class="noticeSuccess" id="notify"><p>選択されたNGワードを削除しました</p></div><?cs /if ?>
<?cs if:Done_filter_load_ngword ?><div class="" id="notify"></div><?cs /if ?>
<?cs else ?>
<?cs if:Code1 ?><div class="noticeFailed" id="notify"><p>実行権限がありません</p></div><?cs /if ?>
<?cs if:Code2 ?><div class="noticeFailed" id="notify"><p>削除するNGワードが選択されていません</p></div><?cs /if ?>
<?cs /if ?>

<p>
現在書き込みを禁止しているNGワードを表示しています。<br />
<a href="<?cs var:html_escape(ZerominScript) ?>?class=filter&amp;method=create_ngword&amp;bbs=<?cs var:html_escape(BBS) ?>&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>" onclick="Zeromin2.redirect(this);return false">NGワードの新規登録はこちらから行ってください。</a><br />
<span class="caution">※注意&nbsp;規制する際はプラグイン一覧の<pre>Img0ch::Plugin::Filter::NGWord</pre>を必ず有効にする必要があります！</span>
</p>

<p>
<select name="method">
  <option value="load_ngword">NGワードの一覧を表示</option>
  <option value="remove_ngword">NGワードの削除</option>
</select>
<input type="submit" value="実行" />
</p>

<p>
ページ単位：
<input type="text" name="item" size="5" value="<?cs var:html_escape(Item) ?>" /><br />
(&nbsp;<?cs var:html_escape(Total) ?>件&nbsp;-&nbsp;現在<?cs var:html_escape(Current) ?>ページ目&nbsp;)<br />
<span class="page">
<?cs if:Prev ?><a href="<?cs var:html_escape(ZerominScript) ?>?class=filter&amp;method=load_ngword&amp;bbs=<?cs var:html_escape(BBS) ?>&amp;by=<?cs var:html_escape(By) ?>&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>&amp;item=<?cs var:html_escape(Item) ?>&amp;offset=<?cs var:html_escape(Prev) ?>" onclick="Zeromin2.redirect(this);return false">&lt;&lt;&nbsp;前</a><?cs /if ?>
<?cs each:item = Pages ?>
<a href="<?cs var:html_escape(ZerominScript) ?>?class=filter&amp;method=load_ngword&amp;bbs=<?cs var:html_escape(BBS) ?>&amp;by=<?cs var:html_escape(By) ?>&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>&amp;item=<?cs var:html_escape(Item) ?>&amp;offset=<?cs var:html_escape(item.num) ?>" onclick="Zeromin2.redirect(this);return false"><?cs var:html_escape(item.num) ?></a>
<?cs /each ?>
<?cs if:Next ?><a href="<?cs var:html_escape(ZerominScript) ?>?class=filter&amp;method=load_ngword&amp;bbs=<?cs var:html_escape(BBS) ?>&amp;by=<?cs var:html_escape(By) ?>&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>&amp;item=<?cs var:html_escape(Item) ?>&amp;offset=<?cs var:html_escape(Next) ?>" onclick="Zeromin2.redirect(this);return false">次&nbsp;&gt;&gt;</a><?cs /if ?>
</span>
</p>

<table class="simple">
  <thead>
  <tr>
    <th><input type="checkbox" name="" value="" onclick="Zeromin2.selectAllCheckbox( this, 'id' )" /></th>
    <th>対象文字列</th>
    <th>対処方法</th>
    <th>置換文字列</th>
  </tr>
  </thead>
  <tbody>
  <?cs each:item = Entries ?>
  <tr>
    <td><input type="checkbox" name="id" value="<?cs var:html_escape(item.id) ?>" /></td>
    <td><a href="<?cs var:html_escape(ZerominScript) ?>?class=filter&amp;method=edit_ngword&amp;id=<?cs var:url_escape(item.id) ?>&amp;bbs=<?cs var:html_escape(BBS) ?>&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>" onclick="Zeromin2.redirect(this);return false"><?cs var:html_escape(item.entry) ?></a></td>
    <td><?cs var:html_escape(item.type) ?></td>
    <td><?cs var:html_escape(item.to) ?></td>
  </tr>
  <?cs /each ?>
  </tbody>
</table>

<p>
  ※「対処方法」の数字について
  <ul>
    <li>1 - 書き込み禁止</li>
    <li>2 - 対象文字列の削除</li>
    <li>4 - 対象文字列を置換文字列に置換</li>
  </ul>
</p>

<div class="formFooter">
<input type="hidden" name="<?cs var:html_escape(SessionName) ?>" value="<?cs var:html_escape(Session) ?>" />
<input type="hidden" name="token" value="<?cs var:html_escape(Token) ?>" />
<input type="hidden" name="class" value="filter" />
<input type="hidden" name="bbs" value="<?cs var:html_escape(BBS) ?>" />
<input type="hidden" name="OK" value="load_ngword" />
<input type="hidden" name="NG" value="load_ngword" />
<br id="endmain" />
</div>

</form>

</div>

<?cs include:"zeromin2/footer.cs" ?>
